@@ -1,17 +1,27 @@
-from functools import cached_property
 import os
+from Crypto.PublicKey.RSA import RsaKey
 from dotenv import load_dotenv
 from enum import StrEnum
+from functools import cached_property
 from pathlib import Path
 from pydantic import BaseModel, Field, model_validator
 from pydantic_settings import BaseSettings
-from typing import Annotated, Self, TypeVar
+from typing import Annotated, Self, TypeVar, overload
 from uuid import UUID
 from maleo.enums.environment import Environment, EnvironmentMixin
 from maleo.enums.service import ServiceKey, FullServiceKeyMixin, ServiceName
+from maleo.enums.system import SystemRole, ListOfSystemRoles
+from maleo.enums.user import UserType
+from maleo.types.boolean import OptBool
+from maleo.types.misc import BytesOrStr
 from maleo.types.string import ListOfStrs, OptStr
+from .mixins.identity import EntityIdentifier
+from .operation.enums import ListOfOperationTypes
 from .security.api_key import validate
+from .security.authentication import SystemCredentials, SystemUser, SystemAuthentication
 from .security.authorization import APIKeyAuthorization
+from .security.enums import Domain
+from .security.token import SystemToken
 
 
 class Execution(StrEnum):
@@ -76,11 +86,31 @@ class ApplicationSettings(BaseSettings):
     EXECUTION: Annotated[
         Execution, Field(Execution.CONTAINER, description="Execution mode")
     ] = Execution.CONTAINER
+    RELOAD: Annotated[OptBool, Field(None, description="Reload")] = None
+
+    @cached_property
+    def reload(self) -> bool:
+        if self.RELOAD is not None:
+            return self.RELOAD
+        else:
+            return (
+                self.EXECUTION is Execution.DIRECT
+                and self.ENVIRONMENT is Environment.LOCAL
+            )
+
     HOST: Annotated[str, Field("127.0.0.1", description="Application's host")] = (
         "127.0.0.1"
     )
     PORT: Annotated[int, Field(8000, description="Application's port")] = 8000
     HOST_PORT: Annotated[int, Field(8000, description="Host's port")] = 8000
+
+    @cached_property
+    def port(self) -> int:
+        if self.EXECUTION is Execution.DIRECT and self.ENVIRONMENT is Environment.LOCAL:
+            return self.HOST_PORT
+        else:
+            return self.PORT
+
     DOCKER_NETWORK: Annotated[
         str, Field("maleo-suite", description="Docker's network")
     ] = "maleo-suite"
@@ -126,10 +156,80 @@ class ApplicationSettings(BaseSettings):
     def authorization(self) -> APIKeyAuthorization:
         return APIKeyAuthorization(credentials=self.API_KEY)
 
+    SA_ID: Annotated[int, Field(..., description="SA's ID", ge=1)]
+    SA_UUID: Annotated[UUID, Field(..., description="SA's UUID")]
+    SA_ROLES: Annotated[
+        ListOfSystemRoles,
+        Field([SystemRole.ADMINISTRATOR], description="SA's Roles", min_length=1),
+    ] = [SystemRole.ADMINISTRATOR]
+    SA_USERNAME: Annotated[str, Field(..., description="SA's Username")]
+    SA_EMAIL: Annotated[str, Field(..., description="SA's Email")]
+
+    @cached_property
+    def authentication(self) -> SystemAuthentication:
+        return SystemAuthentication(
+            credentials=SystemCredentials(
+                user=EntityIdentifier[UserType](
+                    id=self.SA_ID, uuid=self.SA_UUID, type=UserType.SERVICE
+                ),
+                domain_roles=self.SA_ROLES,
+                scopes=["authenticated"]
+                + [f"{Domain.SYSTEM}:{role.value}" for role in self.SA_ROLES],
+            ),
+            user=SystemUser(display_name=self.SA_USERNAME, identity=self.SA_EMAIL),
+        )
+
+    @property
+    def token(self) -> SystemToken:
+        return SystemToken.new(sub=self.SA_UUID)
+
+    @overload
+    def generate_token_string(
+        self,
+        key: RsaKey,
+    ) -> str: ...
+    @overload
+    def generate_token_string(
+        self,
+        key: BytesOrStr,
+        *,
+        password: OptStr = None,
+    ) -> str: ...
+    def generate_token_string(
+        self,
+        key: BytesOrStr | RsaKey,
+        *,
+        password: OptStr = None,
+    ) -> str:
+        return self.token.to_string(key, password=password)
+
     # Infra related settings
+    PUBLISH_HEARTBEAT: Annotated[
+        OptBool, Field(None, description="Whether to publish heartbeat")
+    ] = None
+
+    @cached_property
+    def publish_heartbeat(self) -> bool:
+        if self.PUBLISH_HEARTBEAT is not None:
+            return self.PUBLISH_HEARTBEAT
+        else:
+            return self.ENVIRONMENT in (Environment.STAGING, Environment.PRODUCTION)
+
     PUBLISH_RESOURCE_MEASUREMENT: Annotated[
-        bool, Field(..., description="Whether to publish resource measurement")
-    ]
+        OptBool, Field(None, description="Whether to publish resource measurement")
+    ] = None
+
+    @cached_property
+    def publish_resource_measurement(self) -> bool:
+        if self.PUBLISH_RESOURCE_MEASUREMENT is not None:
+            return self.PUBLISH_RESOURCE_MEASUREMENT
+        else:
+            return self.ENVIRONMENT in (Environment.STAGING, Environment.PRODUCTION)
+
+    # Operation related settings
+    PUBLISHABLE_OPERATIONS: Annotated[
+        ListOfOperationTypes, Field([], description="Publishable operations")
+    ] = []
 
     # Security related settings
     USE_LOCAL_KEY: Annotated[
