@@ -1,4 +1,4 @@
-import logging
+from typing import Awaitable, Callable
 from fastapi import Request, Response, status
 from fastapi.encoders import jsonable_encoder
 from fastapi.exceptions import (
@@ -11,10 +11,12 @@ from fastapi.requests import HTTPConnection
 from fastapi.responses import JSONResponse
 from pydantic import ValidationError
 from starlette.authentication import AuthenticationError
-from maleo.logging.enums import Level, LoggerType
+from maleo.logging.enums import Level
+from maleo.logging.logger import EnvironmentT, ServiceKeyT, Exception as ExceptionLogger
 from maleo.utils.exception import extract_details
 from ..error.constants import ERROR_CODE_STATUS_CODE_MAP
 from ..error.enums import ErrorCode
+from ..google import ListOfPublisherHandlers
 from ..response import (
     UnauthorizedResponse,
     UnprocessableEntityResponse,
@@ -63,19 +65,21 @@ async def http_exception_handler(request: Request, exc: HTTPException) -> JSONRe
     )
 
 
-async def maleo_exception_handler(
-    request: Request, exc: MaleoException | AnyException
-) -> JSONResponse:
-    logger = logging.getLogger(
-        f"{exc.application_context.environment} - {exc.application_context.service_key} - {LoggerType.EXCEPTION}"
-    )
+def create_maleo_exception_handler(
+    logger: ExceptionLogger[EnvironmentT, ServiceKeyT],
+    publishers: ListOfPublisherHandlers = [],
+) -> Callable[[Request, MaleoException], Awaitable[JSONResponse]]:
+    async def maleo_exception_handler(
+        request: Request, exc: MaleoException | AnyException
+    ) -> JSONResponse:
+        exc.log_and_publish_operation(logger, Level.ERROR, publishers)
 
-    exc.operation.log(logger, Level.ERROR)
+        return JSONResponse(
+            content=exc.response.model_dump(mode="json"),
+            status_code=exc.error.spec.status_code,
+        )
 
-    return JSONResponse(
-        content=exc.response.model_dump(mode="json"),
-        status_code=exc.error.spec.status_code,
-    )
+    return maleo_exception_handler
 
 
 async def general_exception_handler(request: Request, exc: Exception) -> Response:
