@@ -3,9 +3,12 @@ from pydantic import BaseModel, ConfigDict, Field
 from typing import Annotated
 
 
-class PubslisherHandler(BaseModel):
+class PublisherHandler(BaseModel):
     model_config = ConfigDict(arbitrary_types_allowed=True)
 
     client: Annotated[PublisherClient, Field(..., description="Publisher client")]
     project_id: Annotated[str, Field(..., description="Project ID")]
     topic_id: Annotated[str, Field(..., description="Topic ID")]
+
+
+ListOfPublisherHandlers = list[PublisherHandler]
