@@ -104,7 +104,7 @@ TYPE_ACTION_MODEL_MAP: Mapping[ResourceOperationType, Type] = {
 }
 
 
-class Factory:
+class ResourceOperationActionFactory:
     @overload
     @staticmethod
     def generate(
@@ -374,7 +374,7 @@ class Factory:
     ) -> Callable[..., AnyResourceOperationAction]:
 
         def dependency(request: Request) -> AnyResourceOperationAction:
-            return Factory.extract(
+            return ResourceOperationActionFactory.extract(
                 type_, request=request, from_state=from_state, strict=strict
             )
 
