@@ -1,4 +1,5 @@
-import traceback
+import os
+from google.cloud.pubsub_v1.publisher.futures import Future
 from logging import Logger
 from typing import Generic
 from maleo.logging.enums import Level
@@ -8,16 +9,18 @@ from maleo.types.dict import (
     StrToAnyDict,
     StrToStrDict,
 )
+from maleo.utils.exception import extract_details
 from maleo.utils.merger import merge_dicts
 from ..application import ApplicationContextMixin
 from ..connection import OptConnectionContextT, ConnectionContextMixin
+from ..google import ListOfPublisherHandlers
 from ..error import OptAnyErrorT, ErrorMixin
 from ..mixins.general import Success
 from ..resource import OptResourceT, ResourceMixin
 from ..response import (
     OptResponseContextT,
     ResponseContextMixin,
-    ResponseT,
+    OptResponseT,
     ResponseMixin,
 )
 from ..security.authentication import (
@@ -31,12 +34,13 @@ from .action import (
     ActionT,
 )
 from .context import ContextMixin
+from .enums import OperationType as OperationTypeEnum, ListOfOperationTypes
 from .mixins import Id, OperationType, Summary, TimestampMixin
 
 
 class BaseOperation(
     ResponseContextMixin[OptResponseContextT],
-    ResponseMixin[ResponseT],
+    ResponseMixin[OptResponseT],
     ImpersonationMixin[OptImpersonation],
     AuthorizationMixin[OptAnyAuthorization],
     AuthenticationMixin[OptAnyAuthentication],
@@ -57,7 +61,7 @@ class BaseOperation(
         BoolT,
         OptAnyErrorT,
         OptConnectionContextT,
-        ResponseT,
+        OptResponseT,
         OptResponseContextT,
     ],
 ):
@@ -184,5 +188,85 @@ class BaseOperation(
                 exc_info=exc_info,
                 extra=extra,
             )
-        except Exception:
-            print(f"Failed logging {self.type} operation:\n{traceback.format_exc()}")
+        except Exception as e:
+            labels = self.log_labels(
+                additional_labels=additional_labels, override_labels=override_labels
+            )
+            logger.error(
+                f"Failed logging {self.type} Operation {self.id}",
+                exc_info=True,
+                extra={
+                    "json_fields": {"exc_details": extract_details(e)},
+                    "labels": labels,
+                },
+            )
+
+    def _is_allowed_to_publish(self) -> bool:
+        # 1. Read from env (comma-separated string)
+        raw_value = os.getenv("PUBLISHABLE_OPERATIONS", "").strip()
+
+        # 2. Parse into list of OperationType
+        publishable_ops: ListOfOperationTypes = []
+        if raw_value:
+            for v in raw_value.split(","):
+                v = v.strip().lower()
+                try:
+                    publishable_ops.append(OperationTypeEnum(v))
+                except ValueError:
+                    continue  # ignore invalid values
+
+        # 3. Check if self.type is allowed
+        return self.type in publishable_ops
+
+    def publish(
+        self,
+        logger: Logger,
+        publishers: ListOfPublisherHandlers = [],
+        *,
+        additional_labels: OptStrToStrDict = None,
+        override_labels: OptStrToStrDict = None,
+    ) -> list[Future]:
+        if not self._is_allowed_to_publish():
+            return []
+
+        labels = self.log_labels(
+            additional_labels=additional_labels, override_labels=override_labels
+        )
+        futures: list[Future] = []
+        for publisher in publishers:
+            topic_path = publisher.client.topic_path(
+                publisher.project_id, publisher.topic_id
+            )
+            try:
+                future: Future = publisher.client.publish(
+                    topic_path,
+                    data=self.model_dump_json().encode(),
+                    **self.application_context.model_dump(mode="json"),
+                )
+                message_id: str = future.result()
+
+                logger.debug(
+                    f"Successfully published {self.type} Operation {self.id} message {message_id} to {topic_path}",
+                    extra={
+                        "json_fields": {
+                            "operation": self.model_dump(mode="json"),
+                            "message_id": message_id,
+                            "topic_path": topic_path,
+                        },
+                        "labels": labels,
+                    },
+                )
+
+                futures.append(future)
+            except Exception as e:
+                logger.error(
+                    f"Failed publishing {self.type} Operation {self.id}",
+                    exc_info=True,
+                    extra={
+                        "json_fields": {"exc_details": extract_details(e)},
+                        "labels": labels,
+                    },
+                )
+                raise
+
+        return futures
