@@ -1,11 +1,9 @@
 from typing import Mapping
-from maleo.enums.status import DataStatus, SequenceOfDataStatuses
+from maleo.enums.status import DataStatus, SeqOfDataStatuses
 from .enums import ResourceOperationStatusUpdateType
 
 
-STATUS_UPDATE_RULES: Mapping[
-    ResourceOperationStatusUpdateType, SequenceOfDataStatuses
-] = {
+STATUS_UPDATE_RULES: Mapping[ResourceOperationStatusUpdateType, SeqOfDataStatuses] = {
     ResourceOperationStatusUpdateType.DELETE: (DataStatus.INACTIVE, DataStatus.ACTIVE),
     ResourceOperationStatusUpdateType.RESTORE: (DataStatus.DELETED,),
     ResourceOperationStatusUpdateType.DEACTIVATE: (DataStatus.ACTIVE,),
