@@ -5,7 +5,7 @@ from ..error import (
     OptAnyErrorT,
     AnyErrorT,
 )
-from ..response import ResponseT, ErrorResponseT, SuccessResponseT
+from ..response import OptResponseT, ErrorResponseT, OptSuccessResponseT
 from .action.system import SystemOperationAction
 from .base import BaseOperation
 from .enums import OperationType
@@ -18,13 +18,13 @@ class SystemOperation(
         BoolT,
         OptAnyErrorT,
         OptConnectionContext,
-        ResponseT,
+        OptResponseT,
         None,
     ],
     Generic[
         BoolT,
         OptAnyErrorT,
-        ResponseT,
+        OptResponseT,
     ],
 ):
     type: OperationType = OperationType.SYSTEM
@@ -47,9 +47,9 @@ class SuccessfulSystemOperation(
     SystemOperation[
         Literal[True],
         None,
-        SuccessResponseT,
+        OptSuccessResponseT,
     ],
-    Generic[SuccessResponseT],
+    Generic[OptSuccessResponseT],
 ):
     success: Literal[True] = True
     error: None = None
