@@ -1,8 +1,8 @@
 from enum import StrEnum
-from maleo.types.string import ListOfStrings
+from maleo.types.string import ListOfStrs
 
 
-class Code(StrEnum):
+class SuccessCode(StrEnum):
     ANY_DATA = "MAL-SCS-ADT-001"
     NO_DATA = "MAL-SCS-NDT-001"
     SINGLE_DATA = "MAL-SCS-SGD-001"
@@ -19,5 +19,5 @@ class Code(StrEnum):
     OPTIONAL_MULTIPLE_DATA = "MAL-SCS-OMD-001"
 
     @classmethod
-    def choices(cls) -> ListOfStrings:
+    def choices(cls) -> ListOfStrs:
         return [e.value for e in cls]
